@@ -1,7 +1,4 @@
-urls = [
-    'login.ccp',
-    'get_set.ccp',
-]
+from . import urls
 
 
 def make_url(base_url, action):
